@@ -6,11 +6,13 @@ import tarfile
 import tempfile
 
 import bioblend.galaxy
-from . import GalaxyTestBase, test_util
+from . import (
+    GalaxyTestBase,
+    test_util,
+)
 
 
 class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
-
     def setUp(self):
         super().setUp()
         self.default_history_name = "buildbot - automated test"
@@ -19,41 +21,43 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
     def test_create_history(self):
         history_name = "another buildbot - automated test"
         new_history = self.gi.histories.create_history(name=history_name)
-        self.assertIsNotNone(new_history['id'])
-        self.assertEqual(new_history['name'], history_name)
-        self.assertIsNotNone(new_history['url'])
+        self.assertIsNotNone(new_history["id"])
+        self.assertEqual(new_history["name"], history_name)
+        self.assertIsNotNone(new_history["url"])
 
     def test_update_history(self):
-        new_name = 'buildbot - automated test renamed'
+        new_name = "buildbot - automated test renamed"
         new_annotation = f"Annotation for {new_name}"
-        new_tags = ['tag1', 'tag2']
-        updated_hist = self.gi.histories.update_history(self.history['id'], name=new_name, annotation=new_annotation, tags=new_tags)
-        if 'id' not in updated_hist:
-            updated_hist = self.gi.histories.show_history(self.history['id'])
-        self.assertEqual(self.history['id'], updated_hist['id'])
-        self.assertEqual(updated_hist['name'], new_name)
-        self.assertEqual(updated_hist['annotation'], new_annotation)
-        self.assertEqual(updated_hist['tags'], new_tags)
+        new_tags = ["tag1", "tag2"]
+        updated_hist = self.gi.histories.update_history(
+            self.history["id"], name=new_name, annotation=new_annotation, tags=new_tags
+        )
+        if "id" not in updated_hist:
+            updated_hist = self.gi.histories.show_history(self.history["id"])
+        self.assertEqual(self.history["id"], updated_hist["id"])
+        self.assertEqual(updated_hist["name"], new_name)
+        self.assertEqual(updated_hist["annotation"], new_annotation)
+        self.assertEqual(updated_hist["tags"], new_tags)
 
     def test_publish_history(self):
         # Verify that searching for published histories does not return the test history
         published_histories = self.gi.histories.get_histories(published=True)
-        self.assertFalse(any(h['id'] == self.history['id'] for h in published_histories))
-        updated_hist = self.gi.histories.update_history(self.history['id'], published=True)
-        if 'id' not in updated_hist:
-            updated_hist = self.gi.histories.show_history(self.history['id'])
-        self.assertEqual(self.history['id'], updated_hist['id'])
-        self.assertTrue(updated_hist['published'])
+        self.assertFalse(any(h["id"] == self.history["id"] for h in published_histories))
+        updated_hist = self.gi.histories.update_history(self.history["id"], published=True)
+        if "id" not in updated_hist:
+            updated_hist = self.gi.histories.show_history(self.history["id"])
+        self.assertEqual(self.history["id"], updated_hist["id"])
+        self.assertTrue(updated_hist["published"])
         # Verify that searching for published histories now returns the test history
         published_histories = self.gi.histories.get_histories(published=True)
-        self.assertTrue(any(h['id'] == self.history['id'] for h in published_histories))
+        self.assertTrue(any(h["id"] == self.history["id"] for h in published_histories))
         # Verify that get_published_histories as an anonymous user also returns the test history
         anonymous_gi = bioblend.galaxy.GalaxyInstance(url=self.gi.base_url, key=None)
         published_histories = anonymous_gi.histories.get_published_histories()
-        self.assertTrue(any(h['id'] == self.history['id'] for h in published_histories))
-        history_from_slug = anonymous_gi.histories.get_published_histories(slug=updated_hist['slug'])
+        self.assertTrue(any(h["id"] == self.history["id"] for h in published_histories))
+        history_from_slug = anonymous_gi.histories.get_published_histories(slug=updated_hist["slug"])
         self.assertTrue(len(history_from_slug) == 1)
-        self.assertEqual(self.history['id'], history_from_slug[0]['id'])
+        self.assertEqual(self.history["id"], history_from_slug[0]["id"])
 
     def test_get_histories(self):
         # Make sure there's at least one value - the one we created
@@ -62,7 +66,7 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
 
         # Check whether id is present, when searched by name
         histories = self.gi.histories.get_histories(name=self.default_history_name)
-        self.assertEqual(len([h for h in histories if h['id'] == self.history['id']]), 1)
+        self.assertEqual(len([h for h in histories if h["id"] == self.history["id"]]), 1)
 
         # TODO: check whether deleted history is returned correctly
         # At the moment, get_histories() returns only not-deleted histories
@@ -75,10 +79,10 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
         # self.assertGreaterEqual(len(all_histories), len(deleted_history))
 
     def test_show_history(self):
-        history_data = self.gi.histories.show_history(self.history['id'])
-        self.assertEqual(self.history['id'], history_data['id'])
-        self.assertEqual(self.history['name'], history_data['name'])
-        self.assertEqual('new', history_data['state'])
+        history_data = self.gi.histories.show_history(self.history["id"])
+        self.assertEqual(self.history["id"], history_data["id"])
+        self.assertEqual(self.history["name"], history_data["name"])
+        self.assertEqual("new", history_data["state"])
 
     def test_show_history_with_contents(self):
         history_id = self.history["id"]
@@ -89,21 +93,21 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
         contents = self.gi.histories.show_history(history_id, contents=True)
         # history has 1 dataset, content length should be 1
         self.assertEqual(len(contents), 1)
-        contents = self.gi.histories.show_history(history_id, contents=True, types=['dataset'])
+        contents = self.gi.histories.show_history(history_id, contents=True, types=["dataset"])
         # filtering for dataset, content length should still be 1
         self.assertEqual(len(contents), 1)
-        contents = self.gi.histories.show_history(history_id, contents=True, types=['dataset_collection'])
+        contents = self.gi.histories.show_history(history_id, contents=True, types=["dataset_collection"])
         # filtering for dataset collection but there's no collection in the history
         self.assertEqual(len(contents), 0)
-        contents = self.gi.histories.show_history(history_id, contents=True, types=['dataset', 'dataset_collection'])
+        contents = self.gi.histories.show_history(history_id, contents=True, types=["dataset", "dataset_collection"])
         self.assertEqual(len(contents), 1)
 
     def test_create_history_tag(self):
-        new_tag = 'tag1'
-        self.gi.histories.create_history_tag(self.history['id'], new_tag)
-        updated_hist = self.gi.histories.show_history(self.history['id'])
-        self.assertEqual(self.history['id'], updated_hist['id'])
-        self.assertIn(new_tag, updated_hist['tags'])
+        new_tag = "tag1"
+        self.gi.histories.create_history_tag(self.history["id"], new_tag)
+        updated_hist = self.gi.histories.show_history(self.history["id"])
+        self.assertEqual(self.history["id"], updated_hist["id"])
+        self.assertIn(new_tag, updated_hist["tags"])
 
     def test_show_dataset(self):
         history_id = self.history["id"]
@@ -130,7 +134,7 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
         self.gi.histories.delete_dataset(history_id, dataset1_id)
         dataset = self.gi.histories.show_dataset(history_id, dataset1_id)
         self.assertTrue(dataset["deleted"])
-        self.assertFalse(dataset['purged'])
+        self.assertFalse(dataset["purged"])
 
     def test_purge_dataset(self):
         history_id = self.history["id"]
@@ -138,13 +142,13 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
         self.gi.histories.delete_dataset(history_id, dataset1_id, purge=True)
         dataset = self.gi.histories.show_dataset(history_id, dataset1_id)
         self.assertTrue(dataset["deleted"])
-        self.assertTrue(dataset['purged'])
+        self.assertTrue(dataset["purged"])
 
     def test_update_dataset(self):
         history_id = self.history["id"]
         dataset1_id = self._test_dataset(history_id)
         updated_dataset = self.gi.histories.update_dataset(history_id, dataset1_id, visible=False)
-        if 'id' not in updated_dataset:
+        if "id" not in updated_dataset:
             updated_dataset = self.gi.histories.show_dataset(history_id, dataset1_id)
         self.assertFalse(updated_dataset["visible"])
 
@@ -154,71 +158,69 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
     # download_dataset() is already tested in TestGalaxyDatasets
 
     def test_delete_history(self):
-        result = self.gi.histories.delete_history(self.history['id'])
-        self.assertTrue(result['deleted'])
+        result = self.gi.histories.delete_history(self.history["id"])
+        self.assertTrue(result["deleted"])
 
         all_histories = self.gi.histories.get_histories()
-        self.assertTrue(not any(d['id'] == self.history['id'] for d in all_histories))
+        self.assertTrue(not any(d["id"] == self.history["id"] for d in all_histories))
 
     def test_undelete_history(self):
-        self.gi.histories.delete_history(self.history['id'])
-        self.gi.histories.undelete_history(self.history['id'])
+        self.gi.histories.delete_history(self.history["id"])
+        self.gi.histories.undelete_history(self.history["id"])
         all_histories = self.gi.histories.get_histories()
-        self.assertTrue(any(d['id'] == self.history['id'] for d in all_histories))
+        self.assertTrue(any(d["id"] == self.history["id"] for d in all_histories))
 
     def test_get_status(self):
-        state = self.gi.histories.get_status(self.history['id'])
-        self.assertEqual('new', state['state'])
+        state = self.gi.histories.get_status(self.history["id"])
+        self.assertEqual("new", state["state"])
 
     def test_get_most_recently_used_history(self):
         most_recently_used_history = self.gi.histories.get_most_recently_used_history()
         # if the user has been created via the API, it does not have
         # a session, therefore no history
         if most_recently_used_history is not None:
-            self.assertIsNotNone(most_recently_used_history['id'])
-            self.assertIsNotNone(most_recently_used_history['name'])
-            self.assertIsNotNone(most_recently_used_history['state'])
+            self.assertIsNotNone(most_recently_used_history["id"])
+            self.assertIsNotNone(most_recently_used_history["name"])
+            self.assertIsNotNone(most_recently_used_history["state"])
 
     def test_download_history(self):
-        jeha_id = self.gi.histories.export_history(
-            self.history['id'], wait=True, maxwait=60)
+        jeha_id = self.gi.histories.export_history(self.history["id"], wait=True, maxwait=60)
         self.assertTrue(jeha_id)
-        tempdir = tempfile.mkdtemp(prefix='bioblend_test_')
-        temp_fn = os.path.join(tempdir, 'export.tar.gz')
+        tempdir = tempfile.mkdtemp(prefix="bioblend_test_")
+        temp_fn = os.path.join(tempdir, "export.tar.gz")
         try:
-            with open(temp_fn, 'wb') as fo:
-                self.gi.histories.download_history(self.history['id'], jeha_id,
-                                                   fo)
+            with open(temp_fn, "wb") as fo:
+                self.gi.histories.download_history(self.history["id"], jeha_id, fo)
             self.assertTrue(tarfile.is_tarfile(temp_fn))
         finally:
             shutil.rmtree(tempdir)
 
     def test_import_history(self):
-        path = test_util.get_abspath(os.path.join('data', 'Galaxy-History-Test-history-for-export.tar.gz'))
+        path = test_util.get_abspath(os.path.join("data", "Galaxy-History-Test-history-for-export.tar.gz"))
         self.gi.histories.import_history(file_path=path)
 
     def test_copy_dataset(self):
         history_id = self.history["id"]
         contents = "1\t2\t3"
         dataset1_id = self._test_dataset(history_id, contents=contents)
-        self.history_id2 = self.gi.histories.create_history('TestCopyDataset')['id']
+        self.history_id2 = self.gi.histories.create_history("TestCopyDataset")["id"]
         copied_dataset = self.gi.histories.copy_dataset(self.history_id2, dataset1_id)
         expected_contents = ("\n".join(contents.splitlines()) + "\n").encode()
-        self._wait_and_verify_dataset(copied_dataset['id'], expected_contents)
+        self._wait_and_verify_dataset(copied_dataset["id"], expected_contents)
         self.gi.histories.delete_history(self.history_id2, purge=True)
 
-    @test_util.skip_unless_galaxy('release_20.09')
+    @test_util.skip_unless_galaxy("release_20.09")
     def test_update_dataset_datatype(self):
         history_id = self.history["id"]
         dataset1_id = self._test_dataset(history_id)
-        self._wait_and_verify_dataset(dataset1_id, b'1\t2\t3\n')
+        self._wait_and_verify_dataset(dataset1_id, b"1\t2\t3\n")
         original_hda = self.gi.datasets.show_dataset(dataset1_id)
-        assert original_hda['extension'] == 'bed'
-        self.gi.histories.update_dataset(history_id, dataset1_id, datatype='tabular')
+        assert original_hda["extension"] == "bed"
+        self.gi.histories.update_dataset(history_id, dataset1_id, datatype="tabular")
         updated_hda = self.gi.datasets.show_dataset(dataset1_id)
-        assert updated_hda['extension'] == 'tabular'
+        assert updated_hda["extension"] == "tabular"
 
-    @test_util.skip_unless_galaxy('release_19.01')
+    @test_util.skip_unless_galaxy("release_19.01")
     def test_get_extra_files(self):
         history_id = self.history["id"]
         dataset_id = self._test_dataset(history_id)
@@ -226,4 +228,4 @@ class TestGalaxyHistories(GalaxyTestBase.GalaxyTestBase):
         self.assertEqual(extra_files, [])
 
     def tearDown(self):
-        self.gi.histories.delete_history(self.history['id'], purge=True)
+        self.gi.histories.delete_history(self.history["id"], purge=True)
