@@ -16,7 +16,7 @@ log = logging.getLogger(__name__)
 
 
 class LibraryClient(Client):
-    module = 'libraries'
+    module = "libraries"
 
     def __init__(self, galaxy_instance):
         super().__init__(galaxy_instance)
@@ -42,11 +42,11 @@ class LibraryClient(Client):
              'name': 'Library from bioblend',
              'url': '/api/libraries/f740ab636b360a70'}
         """
-        payload = {'name': name}
+        payload = {"name": name}
         if description:
-            payload['description'] = description
+            payload["description"] = description
         if synopsis:
-            payload['synopsis'] = synopsis
+            payload["synopsis"] = synopsis
         return self._post(payload)
 
     def delete_library(self, library_id):
@@ -70,7 +70,7 @@ class LibraryClient(Client):
         """
         Get details about a given library item.
         """
-        url = '/'.join((self._make_url(library_id, contents=True), item_id))
+        url = "/".join((self._make_url(library_id, contents=True), item_id))
         return self._get(url=url)
 
     def delete_library_dataset(self, library_id, dataset_id, purged=False):
@@ -95,8 +95,8 @@ class LibraryClient(Client):
             {'deleted': True,
              'id': '60e680a037f41974'}
         """
-        url = '/'.join((self._make_url(library_id, contents=True), dataset_id))
-        return self._delete(payload={'purged': purged}, url=url)
+        url = "/".join((self._make_url(library_id, contents=True), dataset_id))
+        return self._delete(payload={"purged": purged}, url=url)
 
     def update_library_dataset(self, dataset_id, **kwds):
         """
@@ -124,7 +124,7 @@ class LibraryClient(Client):
         :rtype: dict
         :return: details of the updated dataset
         """
-        url = '/'.join((self._make_url(), 'datasets', dataset_id))
+        url = "/".join((self._make_url(), "datasets", dataset_id))
         return self._patch(payload=kwds, url=url)
 
     def show_dataset(self, library_id, dataset_id):
@@ -173,15 +173,23 @@ class LibraryClient(Client):
         time_left = maxwait
         while True:
             dataset = self.show_dataset(library_id, dataset_id)
-            state = dataset['state']
+            state = dataset["state"]
             if state in TERMINAL_STATES:
                 return dataset
             if time_left > 0:
-                log.info("Dataset %s in library %s is in non-terminal state %s. Will wait %i more s", dataset_id, library_id, state, time_left)
+                log.info(
+                    "Dataset %s in library %s is in non-terminal state %s. Will wait %i more s",
+                    dataset_id,
+                    library_id,
+                    state,
+                    time_left,
+                )
                 time.sleep(min(time_left, interval))
                 time_left -= interval
             else:
-                raise DatasetTimeoutException(f"Waited too long for dataset {dataset_id} in library {library_id} to complete")
+                raise DatasetTimeoutException(
+                    f"Waited too long for dataset {dataset_id} in library {library_id} to complete"
+                )
 
     def show_folder(self, library_id, folder_id):
         """
@@ -207,7 +215,7 @@ class LibraryClient(Client):
         :param library_id: library id to find root of
         """
         l = self.show_library(library_id=library_id)
-        return l['root_folder_id']
+        return l["root_folder_id"]
 
     def create_folder(self, library_id, folder_name, description=None, base_folder_id=None):
         """
@@ -234,11 +242,11 @@ class LibraryClient(Client):
             base_folder_id = self._get_root_folder_id(library_id)
         # Compose the payload
         payload = {}
-        payload['name'] = folder_name
-        payload['folder_id'] = base_folder_id
-        payload['create_type'] = 'folder'
+        payload["name"] = folder_name
+        payload["folder_id"] = base_folder_id
+        payload["create_type"] = "folder"
         if description is not None:
-            payload['description'] = description
+            payload["description"] = description
         return self._post(payload, id=library_id, contents=True)
 
     def get_folders(self, library_id, folder_id=None, name=None):
@@ -266,19 +274,19 @@ class LibraryClient(Client):
         """
         if folder_id is not None:
             warnings.warn(
-                'The folder_id parameter is deprecated, use the show_folder() method to view details of a folder for which you know the ID.',
-                category=FutureWarning
+                "The folder_id parameter is deprecated, use the show_folder() method to view details of a folder for which you know the ID.",
+                category=FutureWarning,
             )
         if folder_id is not None and name is not None:
-            raise ValueError('Provide only one argument between name or folder_id, but not both')
+            raise ValueError("Provide only one argument between name or folder_id, but not both")
         library_contents = self.show_library(library_id=library_id, contents=True)
         if folder_id is not None:
-            folder = next((_ for _ in library_contents if _['type'] == 'folder' and _['id'] == folder_id), None)
+            folder = next((_ for _ in library_contents if _["type"] == "folder" and _["id"] == folder_id), None)
             folders = [folder] if folder is not None else []
         elif name is not None:
-            folders = [_ for _ in library_contents if _['type'] == 'folder' and _['name'] == name]
+            folders = [_ for _ in library_contents if _["type"] == "folder" and _["name"] == name]
         else:
-            folders = [_ for _ in library_contents if _['type'] == 'folder']
+            folders = [_ for _ in library_contents if _["type"] == "folder"]
         return folders
 
     def get_libraries(self, library_id=None, name=None, deleted=False):
@@ -306,17 +314,17 @@ class LibraryClient(Client):
         """
         if library_id is not None:
             warnings.warn(
-                'The library_id parameter is deprecated, use the show_library() method to view details of a library for which you know the ID.',
-                category=FutureWarning
+                "The library_id parameter is deprecated, use the show_library() method to view details of a library for which you know the ID.",
+                category=FutureWarning,
             )
         if library_id is not None and name is not None:
-            raise ValueError('Provide only one argument between name or library_id, but not both')
+            raise ValueError("Provide only one argument between name or library_id, but not both")
         libraries = self._get(params={"deleted": deleted})
         if library_id is not None:
-            library = next((_ for _ in libraries if _['id'] == library_id), None)
+            library = next((_ for _ in libraries if _["id"] == library_id), None)
             libraries = [library] if library is not None else []
         if name is not None:
-            libraries = [_ for _ in libraries if _['name'] == name]
+            libraries = [_ for _ in libraries if _["name"] == name]
         return libraries
 
     def show_library(self, library_id, contents=False):
@@ -341,52 +349,49 @@ class LibraryClient(Client):
         This method should not be called directly but instead refer to the
         methods specific for the desired type of data upload.
         """
-        folder_id = keywords.get('folder_id', None)
+        folder_id = keywords.get("folder_id", None)
         if folder_id is None:
             folder_id = self._get_root_folder_id(library_id)
         files_attached = False
         # Compose the payload dict
         payload = {}
-        payload['folder_id'] = folder_id
-        payload['file_type'] = keywords.get('file_type', 'auto')
-        payload['dbkey'] = keywords.get('dbkey', '?')
-        payload['create_type'] = 'file'
+        payload["folder_id"] = folder_id
+        payload["file_type"] = keywords.get("file_type", "auto")
+        payload["dbkey"] = keywords.get("dbkey", "?")
+        payload["create_type"] = "file"
         if keywords.get("roles", None):
             payload["roles"] = keywords["roles"]
-        if keywords.get("link_data_only", None) and keywords['link_data_only'] != 'copy_files':
-            payload["link_data_only"] = 'link_to_files'
-        payload['tag_using_filenames'] = keywords.get('tag_using_filenames', False)
-        if keywords.get('tags'):
-            payload['tags'] = keywords['tags']
-        payload['preserve_dirs'] = keywords.get('preserve_dirs', False)
+        if keywords.get("link_data_only", None) and keywords["link_data_only"] != "copy_files":
+            payload["link_data_only"] = "link_to_files"
+        payload["tag_using_filenames"] = keywords.get("tag_using_filenames", False)
+        if keywords.get("tags"):
+            payload["tags"] = keywords["tags"]
+        payload["preserve_dirs"] = keywords.get("preserve_dirs", False)
         # upload options
-        if keywords.get('file_url', None) is not None:
-            payload['upload_option'] = 'upload_file'
-            payload['files_0|url_paste'] = keywords['file_url']
-        elif keywords.get('pasted_content', None) is not None:
-            payload['upload_option'] = 'upload_file'
-            payload['files_0|url_paste'] = keywords['pasted_content']
-        elif keywords.get('server_dir', None) is not None:
-            payload['upload_option'] = 'upload_directory'
-            payload['server_dir'] = keywords['server_dir']
-        elif keywords.get('file_local_path', None) is not None:
-            payload['upload_option'] = 'upload_file'
-            payload['files_0|file_data'] = attach_file(keywords['file_local_path'])
+        if keywords.get("file_url", None) is not None:
+            payload["upload_option"] = "upload_file"
+            payload["files_0|url_paste"] = keywords["file_url"]
+        elif keywords.get("pasted_content", None) is not None:
+            payload["upload_option"] = "upload_file"
+            payload["files_0|url_paste"] = keywords["pasted_content"]
+        elif keywords.get("server_dir", None) is not None:
+            payload["upload_option"] = "upload_directory"
+            payload["server_dir"] = keywords["server_dir"]
+        elif keywords.get("file_local_path", None) is not None:
+            payload["upload_option"] = "upload_file"
+            payload["files_0|file_data"] = attach_file(keywords["file_local_path"])
             files_attached = True
         elif keywords.get("filesystem_paths", None) is not None:
             payload["upload_option"] = "upload_paths"
             payload["filesystem_paths"] = keywords["filesystem_paths"]
 
         try:
-            return self._post(payload, id=library_id, contents=True,
-                              files_attached=files_attached)
+            return self._post(payload, id=library_id, contents=True, files_attached=files_attached)
         finally:
-            if payload.get('files_0|file_data', None) is not None:
-                payload['files_0|file_data'].close()
+            if payload.get("files_0|file_data", None) is not None:
+                payload["files_0|file_data"].close()
 
-    def upload_file_from_url(self, library_id, file_url, folder_id=None,
-                             file_type='auto', dbkey='?',
-                             tags=None):
+    def upload_file_from_url(self, library_id, file_url, folder_id=None, file_type="auto", dbkey="?", tags=None):
         """
         Upload a file to a library from a URL.
 
@@ -412,14 +417,11 @@ class LibraryClient(Client):
         :rtype: list
         :return: List with a single dictionary containing information about the LDDA
         """
-        return self._do_upload(library_id, file_url=file_url,
-                               folder_id=folder_id, file_type=file_type,
-                               dbkey=dbkey,
-                               tags=tags)
+        return self._do_upload(
+            library_id, file_url=file_url, folder_id=folder_id, file_type=file_type, dbkey=dbkey, tags=tags
+        )
 
-    def upload_file_contents(self, library_id, pasted_content,
-                             folder_id=None, file_type='auto', dbkey='?',
-                             tags=None):
+    def upload_file_contents(self, library_id, pasted_content, folder_id=None, file_type="auto", dbkey="?", tags=None):
         """
         Upload pasted_content to a data library as a new file.
 
@@ -445,14 +447,13 @@ class LibraryClient(Client):
         :rtype: list
         :return: List with a single dictionary containing information about the LDDA
         """
-        return self._do_upload(library_id, pasted_content=pasted_content,
-                               folder_id=folder_id, file_type=file_type,
-                               dbkey=dbkey,
-                               tags=tags)
+        return self._do_upload(
+            library_id, pasted_content=pasted_content, folder_id=folder_id, file_type=file_type, dbkey=dbkey, tags=tags
+        )
 
-    def upload_file_from_local_path(self, library_id, file_local_path,
-                                    folder_id=None, file_type='auto', dbkey='?',
-                                    tags=None):
+    def upload_file_from_local_path(
+        self, library_id, file_local_path, folder_id=None, file_type="auto", dbkey="?", tags=None
+    ):
         """
         Read local file contents from file_local_path and upload data to a
         library.
@@ -479,15 +480,28 @@ class LibraryClient(Client):
         :rtype: list
         :return: List with a single dictionary containing information about the LDDA
         """
-        return self._do_upload(library_id, file_local_path=file_local_path,
-                               folder_id=folder_id, file_type=file_type,
-                               dbkey=dbkey,
-                               tags=tags)
+        return self._do_upload(
+            library_id,
+            file_local_path=file_local_path,
+            folder_id=folder_id,
+            file_type=file_type,
+            dbkey=dbkey,
+            tags=tags,
+        )
 
-    def upload_file_from_server(self, library_id, server_dir, folder_id=None,
-                                file_type='auto', dbkey='?', link_data_only=None,
-                                roles="", preserve_dirs=False, tag_using_filenames=False,
-                                tags=None):
+    def upload_file_from_server(
+        self,
+        library_id,
+        server_dir,
+        folder_id=None,
+        file_type="auto",
+        dbkey="?",
+        link_data_only=None,
+        roles="",
+        preserve_dirs=False,
+        tag_using_filenames=False,
+        tags=None,
+    ):
         """
         Upload all files in the specified subdirectory of the Galaxy library
         import directory to a library.
@@ -540,17 +554,32 @@ class LibraryClient(Client):
           ``library_import_dir`` option configured in the ``config/galaxy.yml``
           configuration file.
         """
-        return self._do_upload(library_id, server_dir=server_dir,
-                               folder_id=folder_id, file_type=file_type,
-                               dbkey=dbkey, link_data_only=link_data_only,
-                               roles=roles, preserve_dirs=preserve_dirs,
-                               tag_using_filenames=tag_using_filenames,
-                               tags=tags)
+        return self._do_upload(
+            library_id,
+            server_dir=server_dir,
+            folder_id=folder_id,
+            file_type=file_type,
+            dbkey=dbkey,
+            link_data_only=link_data_only,
+            roles=roles,
+            preserve_dirs=preserve_dirs,
+            tag_using_filenames=tag_using_filenames,
+            tags=tags,
+        )
 
-    def upload_from_galaxy_filesystem(self, library_id, filesystem_paths, folder_id=None,
-                                      file_type="auto", dbkey="?", link_data_only=None,
-                                      roles="", preserve_dirs=False, tag_using_filenames=False,
-                                      tags=None):
+    def upload_from_galaxy_filesystem(
+        self,
+        library_id,
+        filesystem_paths,
+        folder_id=None,
+        file_type="auto",
+        dbkey="?",
+        link_data_only=None,
+        roles="",
+        preserve_dirs=False,
+        tag_using_filenames=False,
+        tags=None,
+    ):
         """
         Upload a set of files already present on the filesystem of the Galaxy
         server to a library.
@@ -601,14 +630,20 @@ class LibraryClient(Client):
           ``allow_path_paste`` option set to ``true`` in the
           ``config/galaxy.yml`` configuration file.
         """
-        return self._do_upload(library_id, filesystem_paths=filesystem_paths,
-                               folder_id=folder_id, file_type=file_type,
-                               dbkey=dbkey, link_data_only=link_data_only,
-                               roles=roles, preserve_dirs=preserve_dirs,
-                               tag_using_filenames=tag_using_filenames,
-                               tags=tags)
+        return self._do_upload(
+            library_id,
+            filesystem_paths=filesystem_paths,
+            folder_id=folder_id,
+            file_type=file_type,
+            dbkey=dbkey,
+            link_data_only=link_data_only,
+            roles=roles,
+            preserve_dirs=preserve_dirs,
+            tag_using_filenames=tag_using_filenames,
+            tags=tags,
+        )
 
-    def copy_from_dataset(self, library_id, dataset_id, folder_id=None, message=''):
+    def copy_from_dataset(self, library_id, dataset_id, folder_id=None, message=""):
         """
         Copy a Galaxy dataset into a library.
 
@@ -631,10 +666,10 @@ class LibraryClient(Client):
         if folder_id is None:
             folder_id = self._get_root_folder_id(library_id)
         payload = {}
-        payload['folder_id'] = folder_id
-        payload['create_type'] = 'file'
-        payload['from_hda_id'] = dataset_id
-        payload['ldda_message'] = message
+        payload["folder_id"] = folder_id
+        payload["create_type"] = "file"
+        payload["from_hda_id"] = dataset_id
+        payload["ldda_message"] = message
         return self._post(payload, id=library_id, contents=True)
 
     def get_library_permissions(self, library_id):
@@ -647,7 +682,7 @@ class LibraryClient(Client):
         :rtype: dict
         :return: dictionary with all applicable permissions' values
         """
-        url = self._make_url(library_id) + '/permissions'
+        url = self._make_url(library_id) + "/permissions"
         return self._get(url=url)
 
     def get_dataset_permissions(self, dataset_id):
@@ -660,11 +695,10 @@ class LibraryClient(Client):
         :rtype: dict
         :return: dictionary with all applicable permissions' values
         """
-        url = '/'.join((self._make_url(), 'datasets', dataset_id, 'permissions'))
+        url = "/".join((self._make_url(), "datasets", dataset_id, "permissions"))
         return self._get(url=url)
 
-    def set_library_permissions(self, library_id, access_in=None,
-                                modify_in=None, add_in=None, manage_in=None):
+    def set_library_permissions(self, library_id, access_in=None, modify_in=None, add_in=None, manage_in=None):
         """
         Set the permissions for a library. Note: it will override all security
         for this library even if you leave out a permission type.
@@ -689,18 +723,17 @@ class LibraryClient(Client):
         """
         payload = {}
         if access_in:
-            payload['LIBRARY_ACCESS_in'] = access_in
+            payload["LIBRARY_ACCESS_in"] = access_in
         if modify_in:
-            payload['LIBRARY_MODIFY_in'] = modify_in
+            payload["LIBRARY_MODIFY_in"] = modify_in
         if add_in:
-            payload['LIBRARY_ADD_in'] = add_in
+            payload["LIBRARY_ADD_in"] = add_in
         if manage_in:
-            payload['LIBRARY_MANAGE_in'] = manage_in
-        url = self._make_url(library_id) + '/permissions'
+            payload["LIBRARY_MANAGE_in"] = manage_in
+        url = self._make_url(library_id) + "/permissions"
         return self._post(payload, url=url)
 
-    def set_dataset_permissions(self, dataset_id, access_in=None,
-                                modify_in=None, manage_in=None):
+    def set_dataset_permissions(self, dataset_id, access_in=None, modify_in=None, manage_in=None):
         """
         Set the permissions for a dataset. Note: it will override all security
         for this dataset even if you leave out a permission type.
@@ -722,12 +755,12 @@ class LibraryClient(Client):
         """
         payload = {}
         if access_in:
-            payload['access_ids[]'] = access_in
+            payload["access_ids[]"] = access_in
         if modify_in:
-            payload['modify_ids[]'] = modify_in
+            payload["modify_ids[]"] = modify_in
         if manage_in:
-            payload['manage_ids[]'] = manage_in
+            payload["manage_ids[]"] = manage_in
         # we need here to define an action
-        payload['action'] = 'set_permissions'
-        url = '/'.join((self._make_url(), 'datasets', dataset_id, 'permissions'))
+        payload["action"] = "set_permissions"
+        url = "/".join((self._make_url(), "datasets", dataset_id, "permissions"))
         return self._post(payload, url=url)
